---
title: "The Top of My Todo List"
date: "April 2012"
---

A palliative care nurse called Bronnie Ware made a list of the biggest [regrets of the dying](http://bronnieware.com/regrets-of-the-dying/). Her list seems plausible. I could see myself — _can_ see myself — making at least 4 of these 5 mistakes.

If you had to compress them into a single piece of advice, it might be: don't be a cog. The 5 regrets paint a portrait of post-industrial man, who shrinks himself into a shape that fits his circumstances, then turns dutifully till he stops.

The alarming thing is, the mistakes that produce these regrets are all errors of omission. You forget your dreams, ignore your family, suppress your feelings, neglect your friends, and forget to be happy. Errors of omission are a particularly dangerous type of mistake, because you make them by default.

I would like to avoid making these mistakes. But how do you avoid mistakes you make by default? Ideally you transform your life so it has other defaults. But it may not be possible to do that completely. As long as these mistakes happen by default, you probably have to be reminded not to make them. So I inverted the 5 regrets, yielding a list of 5 commands

> Don't ignore your dreams; don't work too much; say what you think; cultivate friendships; be happy.

which I then put at the top of the file I use as a todo list.